@@ -85,3 +85,19 @@ from reminder_texts import (
     ReminderText,
     ReminderTextsIterator
 )
+from suppliers import (
+    Supplier,
+    SuppliersIterator
+)
+from credit_notes import (
+    CreditNote,
+    CreditNotesIterator
+)
+from credit_note_items import (
+    CreditNoteItem,
+    CreditNoteItemsIterator
+)
+from credit_note_tags import (
+    CreditNoteTag,
+    CreditNoteTagsIterator
+)
