@@ -28,7 +28,7 @@ def _invoice_item_xml(
     reduction = None
 ):
     """
-    Creates the XML to add or edit a invoice-item
+    Creates the XML to add or edit an invoice-item
     """
 
     integer_field_names = [
@@ -135,7 +135,7 @@ class InvoiceItem(Item):
         reduction = None
     ):
         """
-        Creates a invoice-item
+        Creates an invoice item
 
         :param conn: Connection-Object
 
@@ -194,7 +194,7 @@ class InvoiceItem(Item):
         reduction = None
     ):
         """
-        Edit a invoice-item
+        Edit an invoice item
 
         :param id: ID of the invoice-item
 
@@ -268,19 +268,24 @@ class InvoiceItems(list):
         fetch_all = False,
         keep_old_items = False,
         page = 1,
-        per_page = None
+        per_page = None,
+
+        invoice_ids = None
     ):
         """
         Fills the list with InvoiceItem-objects
 
-        :param invoice_id: ID of the invoice (mandatory)
+        :param invoice_id: ID of the invoice (mandatory) or a list of IDs.
+            If list with IDs given: The result contains the invoice-items of
+            many invoices. Be careful: Too many invoice IDs can produce to
+            large responses or to large SQL statements.
+            My recommendation: 10-50 invoice IDs at one time.
 
         :param order_by: Sortings consist of the name of the field and
             sort order: ASC for ascending resp. DESC for descending order.
             If no order is specified, ascending order (ASC) is used.
             Nested sort orders are possible. Please separate the sort orders by
             comma.
-
         """
 
         # Check empty param
@@ -304,6 +309,9 @@ class InvoiceItems(list):
             url.query["order_by"] = order_by
 
         # Search parameter
+        if isinstance(invoice_id, (list, tuple)):
+            invoice_id = ",".join(str(id) for id in set(invoice_id))
+
         url.query["invoice_id"] = invoice_id
 
         # Fetch data
@@ -366,6 +374,12 @@ class InvoiceItemsIterator(ItemsIterator):
     ):
         """
         Search
+
+        :param invoice_id: ID of the invoice (mandatory) or a list of IDs.
+            If list with IDs given: The result contains the invoice-items of
+            many invoices. Be careful: To many invoice IDs can produce to
+            large responses or to large SQL statements.
+            My recommendation: 10-50 invoice IDs at one time.
         """
 
         # Params
